@@ -1,4 +1,5 @@
 from datetime import datetime as dt
+import time
 
 import discord
 
@@ -34,7 +35,7 @@ class ConnectEvent(vbu.Cog):
         if not event_webhook:
             return False
         try:
-            avatar_url = str(self.bot.user.avatar_url)
+            avatar_url = str(self.bot.user.avatar.url)
         except Exception:
             avatar_url = None
         try:
@@ -62,7 +63,7 @@ class ConnectEvent(vbu.Cog):
 
         await self.send_webhook(
             "shard_connect",
-            f"Shard connect event just pinged for shard ID `{shard_id}` - {dt.utcnow().strftime('%X.%f')}",
+            f"Shard connect event just pinged for shard ID `{shard_id}` - <t:{int(time.time())}>",
             f"{try_username(self.bot)} - Shard Connect",
             f"Sent webhook for on_shard_connect event in shard `{shard_id}`",
         )
@@ -75,7 +76,7 @@ class ConnectEvent(vbu.Cog):
 
         await self.send_webhook(
             "shard_ready",
-            f"Shard ready event just pinged for shard ID `{shard_id}` - {dt.utcnow().strftime('%X.%f')}",
+            f"Shard ready event just pinged for shard ID `{shard_id}` - <t:{int(time.time())}>",
             f"{try_username(self.bot)} - Shard Ready",
             f"Sent webhook for on_shard_ready event in shard `{shard_id}`",
         )
@@ -88,7 +89,7 @@ class ConnectEvent(vbu.Cog):
 
         await self.send_webhook(
             "bot_ready",
-            f"Bot ready event just pinged for instance with shards `{self.bot.shard_ids}` - {dt.utcnow().strftime('%X.%f')}",
+            f"Bot ready event just pinged for instance with shards `{self.bot.shard_ids}` -<t:{int(time.time())}>",
             f"{try_username(self.bot)} - Ready",
             "Sent webhook for on_ready event",
         )
@@ -101,7 +102,7 @@ class ConnectEvent(vbu.Cog):
 
         await self.send_webhook(
             "shard_disconnect",
-            f"Shard disconnect event just pinged for shard ID `{shard_id}` - {dt.utcnow().strftime('%X.%f')}",
+            f"Shard disconnect event just pinged for shard ID `{shard_id}` - <t:{int(time.time())}>",
             f"{try_username(self.bot)} - Shard Disconnect",
             f"Sent webhook for on_shard_disconnect event in shard `{shard_id}`",
         )
@@ -114,7 +115,7 @@ class ConnectEvent(vbu.Cog):
 
         await self.send_webhook(
             "bot_disconnect",
-            f"Bot disconnect event just pinged for instance with shards `{self.bot.shard_ids or [0]}` - {dt.utcnow().strftime('%X.%f')}",
+            f"Bot disconnect event just pinged for instance with shards `{self.bot.shard_ids or [0]}` - <t:{int(time.time())}>",
             f"{try_username(self.bot)} - Disconnect",
             "Sent webhook for on_disconnect event",
         )
@@ -127,7 +128,7 @@ class ConnectEvent(vbu.Cog):
 
         await self.send_webhook(
             "shard_connect",
-            f"Shard resumed event just pinged for shard ID `{shard_id}` - {dt.utcnow().strftime('%X.%f')}",
+            f"Shard resumed event just pinged for shard ID `{shard_id}` - <t:{int(time.time())}>",
             f"{try_username(self.bot)} - Shard Resumed",
             f"Sent webhook for on_shard_resumed event in shard `{shard_id}`",
         )
@@ -140,7 +141,7 @@ class ConnectEvent(vbu.Cog):
 
         await self.send_webhook(
             "bot_connect",
-            f"Bot resumed event just pinged for instance with shards `{self.bot.shard_ids or [0]}` - {dt.utcnow().strftime('%X.%f')}",
+            f"Bot resumed event just pinged for instance with shards `{self.bot.shard_ids or [0]}` - <t:{int(time.time())}>",
             f"{try_username(self.bot)} - Resumed",
             "Sent webhook for on_resumed event",
         )
@@ -167,9 +168,9 @@ class ConnectEvent(vbu.Cog):
         if guild.me:
             try:
                 member_count = guild.member_count
-                text = f"Removed from guild - ``{guild.name}``/``{guild.id}`` (`{member_count}` members; `{vbu.TimeValue((dt.utcnow() - guild.me.joined_at).total_seconds()).clean_full}` guild duration)"
+                text = f"Removed from guild - ``{guild.name}``/``{guild.id}`` (`{member_count}` members; `{vbu.TimeValue((dt.utcnow() - guild.me.joined_at).total_seconds()).clean_full}` guild duration) - <t:{int(time.time())}>"
             except Exception:
-                text = f"Removed from guild - ``{guild.name}``/``{guild.id}`` (`{vbu.TimeValue((dt.utcnow() - guild.me.joined_at).total_seconds()).clean_full}` guild duration)"
+                text = f"Removed from guild - ``{guild.name}``/``{guild.id}`` (`{vbu.TimeValue((dt.utcnow() - guild.me.joined_at).total_seconds()).clean_full}` guild duration) - <t:{int(time.time())}>"
             await self.send_webhook(
                 "guild_remove",
                 text,
