@@ -50,6 +50,12 @@ bot_support_role_id = 0  # The ID used to determine whether or not the user is p
     topgg_token = ""  # The token used to post data to top.gg.
     discordbotlist_token = ""  # The token used to post data to discordbotlist.com.
 
+# Some simple command data outputs
+[command_Data]
+    guild_invite = ""
+    donate_link = ""
+    website_link = ""
+
 # The info command is the slash command equivelant of "help", giving all relevant data.
 [bot_info]
     enabled = true
@@ -82,7 +88,7 @@ bot_support_role_id = 0  # The ID used to determine whether or not the user is p
     response_type = ""  # The response type given to the redirect URI.
     redirect_uri = ""  # Where the user should be redirected to upon authorizing.
     client_id = ""  #  If not set then will use the bot's ID.
-    scope = "bot"  # The scope that will be generated with the invite link, space seperated (applications.commands for slash).
+    scope = "bot applications.commands"  # The scope that will be generated with the invite link, space seperated (applications.commands for slash).
     permissions = []  # args here are passed directly to discord.Permissions as True.
 
 # This data is passed directly over to `asyncpg.connect()`.
